@@ -167,6 +167,26 @@ class User(Base):
         return self.name
 
 
+class Pseudonym(Base):
+    """
+    Модель "Псевдонимы"
+    """
+
+    __tablename__ = 'pseudonyms'
+
+    id = Column(Integer, primary_key=True)
+    user_id = Column(ForeignKey('users.id'))
+    user = relationship('User')
+    position = Column(Integer)
+    sis_user_id = Column(String(255))
+
+    def __repr__(self):
+        return '<Pseudonym {} (id={})>'.format(self, self.id)
+    
+    def __str__(self):
+        return str(self.user)
+
+
 class Quiz(Base):
     """
     Модель "Тест"
@@ -197,6 +217,7 @@ class Enrollment(Base):
     type = Column(String(255))
     course_section_id = Column(ForeignKey('course_sections.id'))
     course_section = relationship('CourseSection')
+    workflow_state = Column(String(255))
 
     def __repr__(self):
         return '<Enrollment {} (id={})>'.format(self, self.id)
